﻿using ComPDFKit.PDFDocument;
using ComPDFKitViewer.PdfViewer;
using PDF_Office.Model;
using PDF_Office.Model.BOTA;
using Prism.Mvvm;
using Prism.Regions;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace PDF_Office.ViewModels.BOTA
{
    class OutLineControlViewModel : BindableBase, INavigationAware
    {
        private CPDFViewer PDFViewer;
        public ObservableCollection<OutlineNode> Outlinelist { get; set; }

        private bool isInsertHead = false;

        public bool IsInsertHead
        {
            get { return isInsertHead; }
            set
            {
                SetProperty(ref isInsertHead, value);
            }
        }

        public OutLineControlViewModel()
        {
            Outlinelist = new ObservableCollection<OutlineNode>();
        }
        public bool IsNavigationTarget(NavigationContext navigationContext)
        {
            return true;
        }

        public void OnNavigatedFrom(NavigationContext navigationContext)
        {
            return;
        }

        public void OnNavigatedTo(NavigationContext navigationContext)
        {
            navigationContext.Parameters.TryGetValue<CPDFViewer>(ParameterNames.PDFViewer, out PDFViewer);
            if (PDFViewer == null)
            {
                return;
            }
            List<CPDFOutline> datasource = PDFViewer.Document.GetOutlineList();
            Outlinelist.Clear();
            foreach (CPDFOutline item in datasource)
            {
                OutlineNode dto = ConvertCPDFToOutlineNode(item, null);
                if (dto != null)
                {
                    Outlinelist.Add(dto);
                }
            }
        }

        private OutlineNode ConvertCPDFToOutlineNode(CPDFOutline outline, OutlineNode parent)
        {
            OutlineNode node = new OutlineNode();
            if (outline != null)
            {
                node.IsInsertNextLayer = false;
                node.IsInsertCurrentLayer = false;
                node.Outline = outline;
                if (parent != null)
                {
                    node.Parent = parent;
                }
                node.Chlidlist = new ObservableCollection<OutlineNode>();
                if (outline.ChildList.Count > 0)
                {
                    foreach (CPDFOutline item in outline.ChildList)
                    {
                        node.Chlidlist.Add(ConvertCPDFToOutlineNode(item, node));
                    }
                }
            }
            return node;
        }
    }
}
